@@ -22,7 +22,7 @@ enUi = ['button', 'checkbox', 'field', 'column', 'area', 'box', 'role', 'user',
         'RFx', 'search', 'page', 'tab', 'panel', 'option', 'dialog', 'status', 'tag', 'symbol', 'sign', 'label', 'scenario', 'link',
         'auction', 'events', 'checkboxes', 'columns', 'lines', 'answers', 'answer', 'responses', 'response', 'buttons', 'fields',
         'tabs', 'icon', 'icons', 'users', 'widget', 'widgets', 'window', 'windows', 'dialog box', 'dialog boxes', 'modal window',
-        'modal windows', 'dialog window', 'dialog windows', 'homepage']
+        'modal windows', 'dialog window', 'dialog windows', 'homepage', 'folder', 'folders', 'file', 'files', 'project', 'projects']
 
 # Configuração da API de tradução
 
@@ -94,8 +94,7 @@ def ProcessFiles(sourceFile):
                         else:
                             targetContent += piece
                     else:
-                        print(piece)
-                        localized = Translate(piece, langCombo)
+                        localized = Translate(piece, langCombo) if type(Translate(piece, langCombo)) is str else Translate(piece, langCombo)[0]
                         targetContent += localized
             file = codecs.open(targetPaths[i] + '/' + '/'.join(sourceFile.split('/')[1:]), encoding = 'utf-8', mode = 'w+')
             file.write(targetContent)
